@@ -1,5 +1,5 @@
 ##    SimilaR package for R
-##    Copyright (C) 2018-2019 by M. Bartoszuk, M. Gagolewski
+##    Copyright (C) 2018-2020 by M. Bartoszuk, M. Gagolewski
 ##
 ##    This program is free software: you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -15,18 +15,23 @@
 ##    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #' @title
-#' Quantify Similarity of All Pairs of Functions
+#' Quantify the Similarity of Pairs of R Functions
 #'
 #' @description
-#' An implementation of the SimilaR algorithm - a novel method to quantify
-#' the similarity of R functions based on program dependence graphs.
+#' An implementation of the SimilaR algorithm - a method to quantify
+#' the similarity of R functions based on Program Dependence Graphs.
 #' Possible use cases include detection of code clones for improving
 #' software quality and of plagiarism among students' homework assignments.
 #'
-#' \code{SimilaR_fromDirectory} scans for function definition in *.R files
-#' in a given directory and performs pairwise comparisons.
+#' \code{SimilaR_fromDirectory} scans for function definitions in all \code{*.R}
+#' source files in a given directory and performs pairwise comparisons.
 #'
-#' @param dirname path to a directory with *.R source files
+#' \code{SimilaR_fromTwoFunctions} compares the code-base of two function objects.
+#'
+#' @param function1 a first function object to compare
+#' @param function2 a second function object to compare
+#' @param functionNames optional functions' names to be included in the output
+#' @param dirname path to a directory with  source files named \code{*.R}
 #' @param returnType \code{"data.frame"} or \code{"matrix"}; indicates the output object type
 #' @param fileTypes \code{"function"} or \code{"file"}; indicates which pairs
 #' of functions extracted from the source files in \code{dirname} should be compared;
@@ -34,7 +39,7 @@
 #' \code{"file"} compares only the functions defined in different source files
 #' @param aggregation \code{"sym"}, \code{"tnorm"}, or \code{"both"};
 #' specifies which model of similarity asymmetry should be used;
-#' \code{"sym"} means that one (overall) value of similarity is computed;
+#' \code{"sym"} means that one (overall) similarity degree is computed;
 #' \code{"both"} evaluates and returns the degree to which the first function
 #' in a function pair is similar ("contained in", "is subset of") to the
 #' second one, and, separately, the extent to which the second function is
@@ -54,29 +59,60 @@
 #' If \code{returnType} is equal to "data.frame", a data frame
 #' that gives the information about the similarity of the inspected
 #' pairs of functions, row by row, is returned.
-#' Columns of the data frame are as follows:
+#' The data frame has the following columns:
 #' \itemize{
 #'      \item \code{name1} - the name of the first function in a pair
 #'      \item \code{name2} - the name of the second function in a pair
 #'      \item \code{SimilaR} - values in the [0,1] interval as returned by the SimilaR algorithm;
 #'           1 denotes that the functions are equivalent, while 0 means that they are totally dissimilar;
 #'           if \code{aggregation} is equal to \code{"both"}, two similarity values are given:
-#'           the one with suffix \code{"12"}, which means how much the first function is a subset of the second,
-#'           and the another one with suffix \code{"21"} which means how much the second function is a subset of the first one
-#'      \item \code{decision} - 0 or 1; 1 means that two functions are classified as similar, and 0 otherwise.
-#'
+#'           the one with suffix \code{"12"} quantifies the degree to which the first function is a subset of the second,
+#'           and the another one with suffix \code{"21"} measures the extent to which the second function is a subset of the first one
+#'      \item \code{decision} - 0 or 1; 1 means that two functions are classified as similar and 0 otherwise.
 #' }
 #' Rows in the data frame are sorted with respect to the \code{SimilaR}
-#' column (descending).
+#' column (descending). Of course, \code{SimilaR_fromTwoFunctions} gives
+#' a data frame with only one row.
 #'
 #' If \code{returnType} is equal to \code{"matrix"}, a square matrix
 #' is returned. The element at index (i,j) equals to the similarity degree
 #' between the i-th and the j-th function.
 #' When \code{aggregation} is equal to \code{"sym"} or \code{"tnorm"},
 #' the matrix is symmetric.
-#' Column names and row names of the matrix are names of the compared functions.
+#' Column names and row names of the matrix are generated from the names
+#' of the functions being compared.
 #'
 #' @examples
+#' f1 <- function(x) {x*x}
+#' f2 <- function(x,y) {x+y}
+#'
+#' ## A data frame is returned: 1 row, 4 columns
+#' SimilaR_fromTwoFunctions(f1,
+#'                          f2,
+#'                          returnType = "data.frame",
+#'                          aggregation = "tnorm")
+#'
+#' ## Custom names in the returned data frame
+#' SimilaR_fromTwoFunctions(f1,
+#'                          f2,
+#'                          functionNames = c("first", "second"),
+#'                          returnType = "data.frame",
+#'                          aggregation = "tnorm")
+#'
+#' ## A data frame is returned: 1 row, 5 columns
+#' SimilaR_fromTwoFunctions(f1,
+#'                          f2,
+#'                          returnType = "data.frame",
+#'                          aggregation = "both")
+#'
+#' ## A non-symmetric square matrix is returned,
+#' ## with 2 rows and 2 columns
+#' SimilaR_fromTwoFunctions(f1,
+#'                          f2,
+#'                          returnType = "matrix",
+#'                          aggregation = "both")
+#'
+#'
 #' ## Typical example, where we wish to compare the functions from different files,
 #' ## but we do not want to compare the functions from the same file.
 #' ## There will be one value describing the overall similarity level.
@@ -87,7 +123,7 @@
 #'
 #' ## In this example we want to compare every pair of functions: even those
 #' ## defined in the same file. Two (non-symmetric) similarity degrees
-#' ## are output.
+#' ## are reported.
 #' SimilaR_fromDirectory(system.file("testdata","data2",package="SimilaR"),
 #'                       returnType = "data.frame",
 #'                       fileTypes="function",
@@ -123,6 +159,7 @@
 #'
 #' @export
 #' @family SimilaR
+#' @rdname SimilaR_fromDirectory
 SimilaR_fromDirectory <- function(dirname,
                     returnType = c("data.frame","matrix"),
                     fileTypes=c("function", "file"),
@@ -145,3 +182,43 @@ SimilaR_fromDirectory <- function(dirname,
 
   SimilaR_general(parsess, sums, functionNames, returnType, aggregation)
 }
+
+
+
+
+
+#' @export
+#' @rdname SimilaR_fromDirectory
+SimilaR_fromTwoFunctions <- function(function1,
+                                     function2,
+                                     functionNames,
+                                     returnType = c("data.frame","matrix"),
+                                     aggregation = c("tnorm", "sym", "both")
+                                     )
+{
+  if(!is.function(function1))
+    stop("The first argument is not a function.")
+  if(!is.function(function2))
+    stop("The second argument is not a function.")
+  if(!missing(functionNames))
+  {
+    stopifnot(is.character(functionNames))
+    stopifnot(length(functionNames) == 2)
+    functionNames <- make.names(functionNames)
+  }
+
+  returnType <- match.arg(returnType)
+  aggregation <- match.arg(aggregation)
+
+  if(missing(functionNames))
+  {
+    functionNames<-c(make.names(deparse(substitute(function1))), make.names(deparse(substitute(function2))))
+  }
+
+  parsess <- list(parse(text=c(stri_paste(functionNames[[1]], "<-"), deparse(function1))),
+                  parse(text=c(stri_paste(functionNames[[2]], "<-"), deparse(function2))))
+
+  sums<-c(0,1,2)
+
+  SimilaR_general(parsess, sums, functionNames, returnType, aggregation)
+}
